### S3 Browser - Server Requests

<script type="module" src="/web_components/js/elements/ui/WebC__S3_Browser__Server_Requests.mjs"></script>

<webc-s3-browser-server-requests api_path="/api/server/requests-in-s3/list-folders"  ></webc-s3-browser-server-requests>
